@@ -6,9 +6,9 @@ from .IosScrollWrapper import IosScrollWrapper
 from .LoadingWrapper import LoadingWrapper
 from .MobileDropdown import MobileDropdown
 from .Notice import Notice
+from .OperationObserver import OperationObserver
 from .Rotate import Rotate
 from .SelectableBox import SelectableBox
-from .StorageObserver import StorageObserver
 from .TouchableComponent import TouchableComponent
 from .UrlObserver import UrlObserver
 from ._ComponentTemplate import _ComponentTemplate
@@ -22,9 +22,9 @@ __all__ = [
     "LoadingWrapper",
     "MobileDropdown",
     "Notice",
+    "OperationObserver",
     "Rotate",
     "SelectableBox",
-    "StorageObserver",
     "TouchableComponent",
     "UrlObserver",
     "_ComponentTemplate"
